==> haskell-monad-par-extras-0.3.3-46-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-par-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 monad-par-extras
version:              0.3.3
visibility:           public
id:                   monad-par-extras-0.3.3-8ZJdRNPkEPf3b3zS0LySZV
key:                  monad-par-extras-0.3.3-8ZJdRNPkEPf3b3zS0LySZV
license:              BSD-3-Clause
copyright:            (c) Ryan Newton 2012
maintainer:           Ryan Newton <rrnewton@gmail.com>
author:               Ryan Newton, Simon Marlow
stability:            Experimental
homepage:             https://github.com/simonmar/monad-par
synopsis:             Combinators and extra features for Par monads
description:
    The modules below provide additional
    data structures, and other added capabilities
    layered on top of the '\''Par'\'' monad.

category:             Control,Parallelism,Monads
abi:                  282ddba1bc294ee1d98222fbfbfa0715
exposed:              True
exposed-modules:
    Control.Monad.Par.AList Control.Monad.Par.Combinator
    Control.Monad.Par.RNG Control.Monad.Par.State

hidden-modules:       Control.Monad.Par.Pedigree
import-dirs:          /usr/lib/ghc-8.10.2/site-local/monad-par-extras-0.3.3
library-dirs:         /usr/lib/ghc-8.10.2/site-local/monad-par-extras-0.3.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/monad-par-extras-0.3.3
hs-libraries:         HSmonad-par-extras-0.3.3-8ZJdRNPkEPf3b3zS0LySZV
depends:
    abstract-par-0.3.3-81njJRkjRqmAeWCHawvyEp base-4.14.1.0
    cereal-0.5.8.1-56yg04wGStN22upOSM9put deepseq-1.4.4.0 mtl-2.2.2
    random-1.2.0-9ZKOj3LHVp86TAE4mLSgtI transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-monad-par-extras/html/monad-par-extras.haddock

haddock-html:         /usr/share/doc/haskell-monad-par-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-par-extras-0.3.3-47-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-par-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 monad-par-extras
version:              0.3.3
visibility:           public
id:                   monad-par-extras-0.3.3-t4sIrr3fEMHO52IRiJJ8U
key:                  monad-par-extras-0.3.3-t4sIrr3fEMHO52IRiJJ8U
license:              BSD-3-Clause
copyright:            (c) Ryan Newton 2012
maintainer:           Ryan Newton <rrnewton@gmail.com>
author:               Ryan Newton, Simon Marlow
stability:            Experimental
homepage:             https://github.com/simonmar/monad-par
synopsis:             Combinators and extra features for Par monads
description:
    The modules below provide additional
    data structures, and other added capabilities
    layered on top of the '\''Par'\'' monad.

category:             Control,Parallelism,Monads
abi:                  95debc3c3bec512db8317cfcd7248505
exposed:              True
exposed-modules:
    Control.Monad.Par.AList Control.Monad.Par.Combinator
    Control.Monad.Par.RNG Control.Monad.Par.State

hidden-modules:       Control.Monad.Par.Pedigree
import-dirs:          /usr/lib/ghc-8.10.2/site-local/monad-par-extras-0.3.3
library-dirs:         /usr/lib/ghc-8.10.2/site-local/monad-par-extras-0.3.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/monad-par-extras-0.3.3
hs-libraries:         HSmonad-par-extras-0.3.3-t4sIrr3fEMHO52IRiJJ8U
depends:
    abstract-par-0.3.3-81njJRkjRqmAeWCHawvyEp base-4.14.1.0
    cereal-0.5.8.1-56yg04wGStN22upOSM9put deepseq-1.4.4.0 mtl-2.2.2
    random-1.2.0-7whe9vPfCIO8FAl3LEVyJX transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-monad-par-extras/html/monad-par-extras.haddock

haddock-html:         /usr/share/doc/haskell-monad-par-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
